pub fn prove_with_image_precommit(
provable_circuit: HyraxProvableCircuit<G1>,
image_layer_label: &str,
code_layer_label: &str,
image_precommit: HyraxProverInputCommitment<G1>,
committer: &PedersenCommitter<G1>,
blinding_rng: &mut (impl CryptoRng + RngCore),
converter: &mut VandermondeInverse<Fr>,
) -> (HyraxProof<G1>, ProofConfig, HyraxProverInputCommitment<G1>)Expand description
Prove a single instance of the iriscode circuit using the Hyrax proof system and the provided image precommit. This is a helper function for proving the v3 masked iriscode is correct.
Arguments:
inputs: all inputs to the circuit, as MLEs.image_precommit: The precommitment to the image (derived from the image usingcommitter). /// This function is assumed to be called with the prover config set!