pub struct V3Prover {
committer: PedersenCommitter<G1>,
converter: VandermondeInverse<Fr>,
v3_circuit: V3CircuitAndAuxData<Fr>,
prover_config: GKRCircuitProverConfig,
left_iris_proof: Option<HyraxProof<G1>>,
left_mask_proof: Option<HyraxProof<G1>>,
right_iris_proof: Option<HyraxProof<G1>>,
right_mask_proof: Option<HyraxProof<G1>>,
}Expand description
A serializable struct containing the 4 Hyrax proofs needed for the
V3 iris/mask circuit.
To allow for incremental proving, this struct can be initialized empty
and then proofs can be added as the become available.
Serialization is possible at any stage, even if a proof is missing.
Once all proofs are generated, the struct can be finalized into
a V3Proof which can be then passed to the verifier.
Fields
committer: PedersenCommitter<G1>converter: VandermondeInverse<Fr>v3_circuit: V3CircuitAndAuxData<Fr>The Iriscode computation circuit description, along with auxiliary inputs (parameters which are constant for both iris and mask computation), but no image/mask inputs.
prover_config: GKRCircuitProverConfigleft_iris_proof: Option<HyraxProof<G1>>left_mask_proof: Option<HyraxProof<G1>>right_iris_proof: Option<HyraxProof<G1>>right_mask_proof: Option<HyraxProof<G1>>Implementations
Sourceimpl V3Prover
impl V3Prover
pub fn default_committer() -> PedersenCommitter<Bn256Point>
Sourcepub fn new(
prover_config: GKRCircuitProverConfig,
circuit: V3CircuitAndAuxData<Fr>,
) -> Self
pub fn new( prover_config: GKRCircuitProverConfig, circuit: V3CircuitAndAuxData<Fr>, ) -> Self
Generate an empty v3 prover with the given configuration.
Sourcepub fn new_from_proofs(
prover_config: GKRCircuitProverConfig,
circuit: V3CircuitAndAuxData<Fr>,
left_image_proof: HyraxProof<Bn256Point>,
left_mask_proof: HyraxProof<Bn256Point>,
right_image_proof: HyraxProof<Bn256Point>,
right_mask_proof: HyraxProof<Bn256Point>,
) -> Self
pub fn new_from_proofs( prover_config: GKRCircuitProverConfig, circuit: V3CircuitAndAuxData<Fr>, left_image_proof: HyraxProof<Bn256Point>, left_mask_proof: HyraxProof<Bn256Point>, right_image_proof: HyraxProof<Bn256Point>, right_mask_proof: HyraxProof<Bn256Point>, ) -> Self
Generate a v3 prover with the given configuration, initialized with optional proofs.
pub fn prove( &mut self, is_mask: bool, is_left_eye: bool, image_bytes: Vec<u8>, image_precommit: HyraxProverInputCommitment<Bn256Point>, rng: &mut (impl CryptoRng + RngCore), ) -> HyraxProverInputCommitment<Bn256Point>
Sourcepub fn set(
&mut self,
is_mask: bool,
is_left_eye: bool,
proof: HyraxProof<Bn256Point>,
)
pub fn set( &mut self, is_mask: bool, is_left_eye: bool, proof: HyraxProof<Bn256Point>, )
Set the field indicated by is_mask and is_left_eye to proof,
overwritting any existing value.
Sourcepub fn set_left_iris_proof(&mut self, proof: HyraxProof<Bn256Point>)
pub fn set_left_iris_proof(&mut self, proof: HyraxProof<Bn256Point>)
Set the left image proof to proof, overwritting any existing value.
Sourcepub fn set_left_mask_proof(&mut self, proof: HyraxProof<Bn256Point>)
pub fn set_left_mask_proof(&mut self, proof: HyraxProof<Bn256Point>)
Set the left mask proof to proof, overwritting any existing value.
Sourcepub fn set_right_iris_proof(&mut self, proof: HyraxProof<Bn256Point>)
pub fn set_right_iris_proof(&mut self, proof: HyraxProof<Bn256Point>)
Set the right image proof to proof, overwritting any existing value.
Sourcepub fn set_right_mask_proof(&mut self, proof: HyraxProof<Bn256Point>)
pub fn set_right_mask_proof(&mut self, proof: HyraxProof<Bn256Point>)
Set the right mask proof to proof, overwritting any existing value.
Sourcepub fn is_set(&self, is_mask: bool, is_left_eye: bool) -> bool
pub fn is_set(&self, is_mask: bool, is_left_eye: bool) -> bool
Returns whether the proof corresponding to is_mask and is_left_eye
is present. If true, then self.get() is guaranteed to return Some
value.
Sourcepub fn get(
&self,
is_mask: bool,
is_left_eye: bool,
) -> Option<&HyraxProof<Bn256Point>>
pub fn get( &self, is_mask: bool, is_left_eye: bool, ) -> Option<&HyraxProof<Bn256Point>>
Get the proof indicated by is_mask and is_left_eye, if any,
otherwise return None.
Sourcepub fn get_left_iris_proof(&self) -> Option<&HyraxProof<Bn256Point>>
pub fn get_left_iris_proof(&self) -> Option<&HyraxProof<Bn256Point>>
Return a reference to the left image proof, if any, otherwise return
None.
Sourcepub fn get_left_mask_proof(&self) -> Option<&HyraxProof<Bn256Point>>
pub fn get_left_mask_proof(&self) -> Option<&HyraxProof<Bn256Point>>
Return a reference to the left mask proof, if any, otherwise return
None.
Sourcepub fn get_right_iris_proof(&self) -> Option<&HyraxProof<Bn256Point>>
pub fn get_right_iris_proof(&self) -> Option<&HyraxProof<Bn256Point>>
Return a reference to the right image proof, if any, otherwise return
None.
Sourcepub fn get_right_mask_proof(&self) -> Option<&HyraxProof<Bn256Point>>
pub fn get_right_mask_proof(&self) -> Option<&HyraxProof<Bn256Point>>
Return a reference to the right mask proof, if any, otherwise return
None.
Sourcefn is_ready_to_finalize(&self) -> bool
fn is_ready_to_finalize(&self) -> bool
Checks whether self is ready to be finalized, i.e. whether all 4
proofs are present.`
Sourcepub fn finalize(&self) -> Result<V3Proof, V3ProofError>
pub fn finalize(&self) -> Result<V3Proof, V3ProofError>
If self is ready to be finalized, it generates a V3Proof containing
all 4 proofs in self along with the ProofConfig used to generate
them.
Returns None if not all proofs are present.
Sourcepub fn deserialize(serialized_prover: &[u8]) -> Self
pub fn deserialize(serialized_prover: &[u8]) -> Self
Deserializes serialized_proof and returns it.
Sourcepub fn get_as_mut(
&mut self,
is_mask: bool,
is_left_eye: bool,
) -> &mut HyraxProof<Bn256Point>
pub fn get_as_mut( &mut self, is_mask: bool, is_left_eye: bool, ) -> &mut HyraxProof<Bn256Point>
Get a mutable reference to the proof indicated by is_mask and is_left_eye.